/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.data.modeller.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;
import org.kie.workbench.common.forms.data.modeller.model.DataObjectFormModel;

public interface DataModellerIntegrationConstants {

    @TranslationKey(defaultValue = "Data Object")
    String DataObject = DataObjectFormModel.class.getName();

    @TranslationKey(defaultValue = "There's no Data Object selected")
    String InvalidDataObject = "DataObjectFormModelCreationPresenter.InvalidDataObject";

    @TranslationKey(defaultValue = " (dependency)")
    String DataObjectFormModelCreationViewImplDependency = "DataObjectFormModelCreationViewImpl.Dependency";
}
